/**
 * Copyright Copyright 2008-14 Simon Andrews
 *
 *    This file is part of FocalPoint.
 *
 *    FocalPoint is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    FocalPoint is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with StackMeasure; if not, write to the Free Software
 *    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package uk.ac.bbsrc.babraham.FocalPoint.GUI.Thumbnail;

/*
 * I'm using an embedded copy of LSMReader rather than linking to
 * the LSM toolbox because when you open a file with the toolbox
 * it always flashes up an ImageJ window (which them immediately
 * closes).  I'd like to not have this imported code but just link
 * to the packaged .jar and will hopefully be able to do this in
 * future.
 * 
 * There's also a problem with using the LSM_Reader jar in that it
 * puts all of its classes in the default package which seems to
 * prevent eclipse (or maybe java generally) from importing them.
 */
import gov.nih.info.rsb.imagej.LSMReader;
import ij.ImagePlus;
import java.io.File;
import java.io.IOException;

public class LSMThumbnailPanel extends ThumbnailPanel {

	private static final LSMReader lsmReader = new LSMReader();
	
	public LSMThumbnailPanel (FileDetailsPanel fileDetails) throws IncompatibleFileTypeException {
		super(fileDetails);
	}

	public ImagePlus [] loadImages (File file) throws IOException {
		return lsmReader.open(file.getParent(), file.getName(), false, false);
	}

	boolean isImage() {
		return true;
	}

	long getFileSize(File file) {
		return file.length();
	}

	boolean shouldDeferLoading(File file) {
		// 50MB for this file
		if (file.length() > (50*1024*1024)) {
			return  true;
		}
		return false;
	}

	boolean canReadFile(File file) {
		if (fileDetails.file().getName().toLowerCase().endsWith(".lsm")) {
			return true;
		}
		return false;
	}

	
}
